@@ -5,6 +5,7 @@ from __future__ import print_function
 import gtk
 
 from taskindicator import util
+from taskindicator.taskw import Task
 
 
 class Dialog(gtk.Window):
@@ -76,13 +77,17 @@ class Dialog(gtk.Window):
         hbox = gtk.HBox(homogeneous=False, spacing=4)
         self.vbox.pack_start(hbox, expand=False, fill=True)
 
-        self.show_all_button = gtk.CheckButton("Show all")
+        self.show_all_button = gtk.CheckButton("Show completed")
         hbox.pack_start(self.show_all_button, expand=True, fill=True)
 
         self.close_button = gtk.Button("Close")
         hbox.pack_end(self.close_button, expand=False, fill=False)
 
+        self.add_button = gtk.Button("Add...")
+        hbox.pack_end(self.add_button, expand=False, fill=False)
+
     def setup_signals(self):
+        self.add_button.connect("clicked", self._on_add_clicked)
         self.close_button.connect("clicked", self._on_close)
         self.show_all_button.connect("clicked", self._on_show_all)
         self.connect("delete_event", self._on_delete)
@@ -149,9 +154,10 @@ class Dialog(gtk.Window):
         return True
 
     def _on_row_activated(self, view, row, column):
+        """Open a task editor dialog."""
         model = view.get_model()
         uuid = model[row][0]
-        self.hide()
+        # self.hide()
         self.on_activate_task(uuid)
 
     def _on_query_changed(self, ctl):
@@ -163,6 +169,9 @@ class Dialog(gtk.Window):
     def _on_close(self, widget):
         self.hide()
 
+    def _on_add_clicked(self, widget):
+        self.on_activate_task(None)
+
     def _on_show_all(self, widget):
         self.refresh_table()
 
